        function getF(rr,cc){
       if(rr==3 && cc==0){return '../../SIN/042/cl0_tz_500.png';}
       if(rr==3 && cc==1){return '../../SIN/042/cl1_tz_500.png';}
       if(rr==3 && cc==2){return '../../SIN/042/cl2_tz_500.png';}
       if(rr==17 && cc==0){return 'prob_tp_thr1_cl0.png';}
       if(rr==17 && cc==1){return 'prob_tp_thr1_cl1.png';}
       if(rr==17 && cc==2){return 'prob_tp_thr1_cl2.png';}
       if(rr==19 && cc==0){return 'prob_tp_thr2_cl0.png';}
       if(rr==19 && cc==1){return 'prob_tp_thr2_cl1.png';}
       if(rr==19 && cc==2){return 'prob_tp_thr2_cl2.png';}
       if(rr==20 && cc==0){return 'prob_tp_thr5_cl0.png';}
       if(rr==20 && cc==1){return 'prob_tp_thr5_cl1.png';}
       if(rr==20 && cc==2){return 'prob_tp_thr5_cl2.png';}
       if(rr==21 && cc==0){return 'prob_tp_thr10_cl0.png';}
       if(rr==21 && cc==1){return 'prob_tp_thr10_cl1.png';}
       if(rr==21 && cc==2){return 'prob_tp_thr10_cl2.png';}
       if(rr==22 && cc==0){return 'prob_tp_thr20_cl0.png';}
       if(rr==22 && cc==1){return 'prob_tp_thr20_cl1.png';}
       if(rr==22 && cc==2){return 'prob_tp_thr20_cl2.png';}
}
