        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260602 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260602 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>7</strong> miembros: 26 <br>1,2,4,5,6,7,11,13,15,17,18,21,25,26,28,30,31,33,34,35,36,40,43,45,48,49';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260602 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 25 <strong>control</strong><br>0,3,8,9,10,12,14,16,19,20,22,23,24,27,29,32,37,38,39,41,42,44,46,47,50';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260602 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260602 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>7</strong> miembros: 26 <br>1,2,4,5,6,7,11,13,15,17,18,21,25,26,28,30,31,33,34,35,36,40,43,45,48,49';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260602 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 25 <strong>control</strong><br>0,3,8,9,10,12,14,16,19,20,22,23,24,27,29,32,37,38,39,41,42,44,46,47,50';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260602 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260602 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>7</strong> miembros: 26 <br>1,2,4,5,6,7,11,13,15,17,18,21,25,26,28,30,31,33,34,35,36,40,43,45,48,49';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260602 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 25 <strong>control</strong><br>0,3,8,9,10,12,14,16,19,20,22,23,24,27,29,32,37,38,39,41,42,44,46,47,50';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260602 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260602 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>7</strong> miembros: 26 <br>1,2,4,5,6,7,11,13,15,17,18,21,25,26,28,30,31,33,34,35,36,40,43,45,48,49';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260602 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 25 <strong>control</strong><br>0,3,8,9,10,12,14,16,19,20,22,23,24,27,29,32,37,38,39,41,42,44,46,47,50';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260602 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260602 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>7</strong> miembros: 26 <br>1,2,4,5,6,7,11,13,15,17,18,21,25,26,28,30,31,33,34,35,36,40,43,45,48,49';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260602 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>8</strong> miembros: 25 <strong>control</strong><br>0,3,8,9,10,12,14,16,19,20,22,23,24,27,29,32,37,38,39,41,42,44,46,47,50';}
}
